@@ -45,70 +45,92 @@ class Ms2Spectra:
     charge_spectra: list[float]
 
     @property
-    def parent_id(self) -> Union[str, None]: return self.info.get(ILineKeywords.PARENT_ID_KEYWORD)
+    def parent_id(self) -> Union[int, None]:
+        parent_id = self.info.get(ILineKeywords.PARENT_ID_KEYWORD.value)
+        return int(parent_id) if parent_id else None
 
     @parent_id.setter
-    def parent_id(self, parent_id: Union[str, int]): self.info[ILineKeywords.PARENT_ID_KEYWORD] = str(parent_id)
+    def parent_id(self, parent_id: Union[str, int]): self.info[ILineKeywords.PARENT_ID_KEYWORD.value] = parent_id
 
     @property
-    def precursor_id(self) -> Union[str, None]: return self.info.get(ILineKeywords.PRECURSOR_ID_KEYWORD)
+    def precursor_id(self) -> Union[int, None]:
+        precursor_id =  self.info.get(ILineKeywords.PRECURSOR_ID_KEYWORD.value)
+        return int(precursor_id) if precursor_id else None
 
     @precursor_id.setter
-    def precursor_id(self, precursor_id: Union[str, int]): self.info[ILineKeywords.PRECURSOR_ID_KEYWORD] = str(precursor_id)
+    def precursor_id(self, precursor_id: Union[str, int]): self.info[ILineKeywords.PRECURSOR_ID_KEYWORD.value] = precursor_id
 
     @property
-    def ook0(self) -> Union[str, None]: return self.info.get(ILineKeywords.OOK0_KEYWORD)
+    def ook0(self) -> Union[float, None]:
+        ook0 = self.info.get(ILineKeywords.OOK0_KEYWORD.value)
+        return float(ook0) if ook0 else None
 
     @ook0.setter
-    def ook0(self, ook0: Union[str, float]): self.info[ILineKeywords.OOK0_KEYWORD] = str(ook0)
+    def ook0(self, ook0: Union[str, float]): self.info[ILineKeywords.OOK0_KEYWORD.value] = ook0
 
     @property
-    def ccs(self) -> Union[str, None]: return self.info.get(ILineKeywords.CCS_KEYWORD)
+    def ccs(self) -> Union[float, None]:
+        ccs = self.info.get(ILineKeywords.CCS_KEYWORD.value)
+        return float(ccs) if ccs else None
 
     @ccs.setter
-    def ccs(self, ccs: Union[str, float]): self.info[ILineKeywords.CCS_KEYWORD] = str(ccs)
+    def ccs(self, ccs: Union[str, float]): self.info[ILineKeywords.CCS_KEYWORD.value] = ccs
 
     @property
-    def rt(self) -> Union[str, None]: return self.info.get(ILineKeywords.RETENTION_TIME_KEYWORD)
+    def rt(self) -> Union[float, None]:
+        rt = self.info.get(ILineKeywords.RETENTION_TIME_KEYWORD.value)
+        return float(rt) if rt else None
 
     @rt.setter
-    def rt(self, rt: Union[str, float]): self.info[ILineKeywords.RETENTION_TIME_KEYWORD] = str(rt)
+    def rt(self, rt: Union[str, float]): self.info[ILineKeywords.RETENTION_TIME_KEYWORD.value] = rt
 
     @property
-    def ce(self) -> Union[str, None]: return self.info.get(ILineKeywords.COLLISION_ENERGY_KEYWORD)
+    def ce(self) -> Union[float, None]:
+        ce =  self.info.get(ILineKeywords.COLLISION_ENERGY_KEYWORD.value)
+        return float(ce) if ce else None
 
     @ce.setter
-    def ce(self, ce: Union[str, float]): self.info[ILineKeywords.COLLISION_ENERGY_KEYWORD] = str(ce)
+    def ce(self, ce: Union[str, float]): self.info[ILineKeywords.COLLISION_ENERGY_KEYWORD.value] = ce
 
     @property
-    def iso_mz(self) -> Union[str, None]: return self.info.get(ILineKeywords.ISOLATION_MZ_KEYWORD)
+    def iso_mz(self) -> Union[float, None]:
+        iso_mz = self.info.get(ILineKeywords.ISOLATION_MZ_KEYWORD.value)
+        return float(iso_mz) if iso_mz else None
 
     @iso_mz.setter
-    def iso_mz(self, iso_mz: Union[str, float]): self.info[ILineKeywords.ISOLATION_MZ_KEYWORD] = str(iso_mz)
+    def iso_mz(self, iso_mz: Union[str, float]): self.info[ILineKeywords.ISOLATION_MZ_KEYWORD.value] = iso_mz
 
     @property
-    def iso_width(self) -> Union[str, None]: return self.info.get(ILineKeywords.ISOLATION_WIDTH_KEYWORD)
+    def iso_width(self) -> Union[float, None]:
+        iso_width = self.info.get(ILineKeywords.ISOLATION_WIDTH_KEYWORD.value)
+        return float(iso_width) if iso_width else None
 
     @iso_width.setter
-    def iso_width(self, iso_width: Union[str, float]): self.info[ILineKeywords.ISOLATION_WIDTH_KEYWORD] = str(iso_width)
+    def iso_width(self, iso_width: Union[str, float]): self.info[ILineKeywords.ISOLATION_WIDTH_KEYWORD.value] = iso_width
 
     @property
-    def scan_begin(self) -> Union[str, None]: return self.info.get(ILineKeywords.SCAN_NUMBER_BEGIN_KEYWORD)
+    def scan_begin(self) -> Union[int, None]:
+        scan_begin = self.info.get(ILineKeywords.SCAN_NUMBER_BEGIN_KEYWORD.value)
+        return int(scan_begin) if scan_begin else None
 
     @scan_begin.setter
-    def scan_begin(self, scan_begin: Union[str, int]): self.info[ILineKeywords.SCAN_NUMBER_BEGIN_KEYWORD] = str(scan_begin)
+    def scan_begin(self, scan_begin: Union[str, int]): self.info[ILineKeywords.SCAN_NUMBER_BEGIN_KEYWORD.value] = scan_begin
 
     @property
-    def scan_end(self) -> Union[int, None]: return self.info.get(ILineKeywords.SCAN_NUMBER_END_KEYWORD)
+    def scan_end(self) -> Union[int, None]:
+        scan_end = self.info.get(ILineKeywords.SCAN_NUMBER_END_KEYWORD.value)
+        return int(scan_end) if scan_end else None
 
     @scan_end.setter
-    def scan_end(self, scan_end: Union[str, int]): self.info[ILineKeywords.SCAN_NUMBER_END_KEYWORD] = str(scan_end)
+    def scan_end(self, scan_end: Union[str, int]): self.info[ILineKeywords.SCAN_NUMBER_END_KEYWORD.value] = scan_end
 
     @property
-    def prec_intensity(self) -> Union[str, None]: return self.info.get(ILineKeywords.PRECURSOR_INTENSITY_KEYWORD)
+    def prec_intensity(self) -> Union[float, None]:
+        prec_intensity = self.info.get(ILineKeywords.PRECURSOR_INTENSITY_KEYWORD.value)
+        return float(prec_intensity) if prec_intensity else None
 
     @prec_intensity.setter
-    def prec_intensity(self, prec_intensity: Union[str, float]): self.info[ILineKeywords.PRECURSOR_INTENSITY_KEYWORD] = str(prec_intensity)
+    def prec_intensity(self, prec_intensity: Union[str, float]): self.info[ILineKeywords.PRECURSOR_INTENSITY_KEYWORD.value] = prec_intensity
 
     def serialize(self) -> str:
         return _serialize_ms2_spectra(self)
@@ -250,7 +272,7 @@ def from_ms2(ms2_input: str | _io.TextIOWrapper, include_spectra=True, processes
 
 def to_ms2(h_lines: list[str], ms2_spectras: list[Ms2Spectra]) -> str:
     lines = []
-    for h_line in h_lines:  # Write header lines
+    for h_line in h_lines:
         if h_line.endswith('\n'):
             lines.append(h_line)
         else:
